# TOAR II Database

### Models



#### Contact

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| person | [Person](#person) |  | Yes |
| organisation | [Organisation](#organisation) |  | Yes |

#### Coordinates

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| lat | number | longitude coordinate of station (decimal degrees_east). This is our best estimate of the station location which is not always identical to the official station coordinates (see coordinate_validation_status). | No |
| lng | number | latitude coordinate of station (decimal degrees_north). This is our best estimate of the station location which is not always identical to the official station coordinates (see coordinate_validation_status). | No |
| alt | number | altitude of station (in m above sea level). This is our best estimate of the station altitude, which is not always identical to the reported station altitude, but frequently uses the elevation from google earth instead (see coordinate_validation_status). | No |

#### Data

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| datetime | dateTime | date and time of observation | Yes |
| value | number | variable value at datetime | Yes |
| flags | string | flags | Yes |
| timeseries_id | integer | ID of timeseries | Yes |

#### Organisation

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| name | string | Short name (abbreviation) of organisation | Yes |
| longname | string | Long name of organisation | Yes |
| kind | string | Kind of organisation | Yes |
| city | string | City where organisation resides | Yes |
| postcode | string | Postcode of organisation city | Yes |
| street_address | string | Street address of organisation city | Yes |
| country | string | Country to which organisation belongs | Yes |
| homepage | string | Homepage of organisation | Yes |

#### Person

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| name | string | Name of person | Yes |
| email | string | Email address of person | Yes |
| phone | string | Phone number of person | Yes |
| isprivate | boolean | Set this flag to true if the contact details shall not be exposed publicly | Yes |

#### Stationmeta

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| codes | [ string ] | list of station's codes | Yes |
| name | string |  | Yes |
| coordinates | [Coordinates](#coordinates) |  | Yes |
| country | string |  | Yes |
| state | string |  | Yes |
| coordinate_validation_status | string |  | Yes |
| coordinate_validation_date | dateTime |  | Yes |
| type_of_environment | string |  | Yes |
| type_of_area | string |  | Yes |
| timezone | string |  | Yes |
| additional_metadata | string (json-string) |  | No |
| coordinate_validator_id | integer |  | Yes |
| roles | [ [StationmetaRole](#stationmetarole) ] |  | No |
| annotations | [ [StationmetaAnnotation](#stationmetaannotation) ] |  | No |
| aux_images | [ [StationmetaAuxImage](#stationmetaauximage) ] |  | No |
| aux_docs | [ [StationmetaAuxDoc](#stationmetaauxdoc) ] |  | No |
| aux_urls | [ [StationmetaAuxUrl](#stationmetaauxurl) ] |  | No |
| globalmeta | [StationmetaGlobal](#stationmetaglobal) |  | No |

#### StationmetaAnnotation

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| kind | integer |  | Yes |
| text | string |  | Yes |
| date_added | dateTime |  | Yes |
| approved | boolean |  | Yes |
| contributor_id | integer |  | Yes |

#### StationmetaAuxDoc

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| resource_description | string |  | Yes |
| date_added | dateTime |  | Yes |
| resource | string |  | Yes |
| station_id | integer |  | Yes |

#### StationmetaAuxImage

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| resource_description | string |  | Yes |
| date_added | dateTime |  | Yes |
| resource | string |  | Yes |
| image_height | integer |  | Yes |
| image_width | integer |  | Yes |
| station_id | integer |  | Yes |

#### StationmetaAuxUrl

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| resource_description | string |  | Yes |
| date_added | dateTime |  | Yes |
| resource | string |  | Yes |
| station_id | integer |  | Yes |

#### StationmetaCore

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| codes | [ string ] | list of station's codes | Yes |
| name | string |  | Yes |
| coordinates | [Coordinates](#coordinates) |  | Yes |
| country | string |  | Yes |
| state | string |  | Yes |
| coordinate_validation_status | string |  | Yes |
| coordinate_validation_date | dateTime |  | Yes |
| type_of_environment | string |  | Yes |
| type_of_area | string |  | Yes |
| timezone | string |  | Yes |
| additional_metadata | string (json-string) |  | No |
| coordinate_validator_id | integer |  | Yes |

#### StationmetaGlobal

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| population_density_year2010 | number |  | Yes |
| max_population_density_25km_year2010 | number |  | Yes |
| climatic_zone | string |  | Yes |
| nightlight_1km_year2013 | number |  | Yes |
| nightlight_5km_year2013 | number |  | Yes |
| max_nightlight_25km_year2013 | number |  | Yes |
| wheat_production_year2000 | number |  | Yes |
| rice_production_year2000 | number |  | Yes |
| edgar_htap_v2_nox_emissions_year2010 | number |  | Yes |
| omi_no2_column_years2011to2015 | number |  | Yes |
| htap_region_tier1 | string |  | Yes |
| etopo_alt | number |  | Yes |
| etopo_min_alt_5km | number |  | Yes |
| etopo_relative_alt | number |  | Yes |
| dominant_landcover_year2012 | string |  | Yes |
| toar1_category | string |  | Yes |
| station_id | integer |  | Yes |

#### StationmetaRole

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| role | string |  | Yes |
| status | string |  | Yes |
| contact_id | integer |  | Yes |

#### Timeseries

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| label | string | a short string to distinguish this timeseries from others with the same combination of station and variable | Yes |
| order | integer | indicates position of this timeseries in a list when several timeseries share the same station and variable combination | Yes |
| access_rights | string | Access rights of timeseries data | Yes |
| sampling_frequency | string | Sampling frequency of data in this timeseries | Yes |
| aggregation | string | Aggregation type in this timeseries | Yes |
| source | string |  | Yes |
| data_start_date | dateTime | Start date of the variable data available for this station | Yes |
| data_end_date | dateTime | End date of the variable data available for this station | Yes |
| measurement_method | string | instrument principle of measurement | Yes |
| sampling_height | number | Height above the ground of the inlet/instrument/sampler (in m) | Yes |
| date_added | dateTime | Date of timeseries metadata entry into TOAR database | Yes |
| date_modified | dateTime | Date of last timeseries metadata modification | Yes |
| additional_metadata | string (json-string) | Additional information about the timeseries as JSON structure. | Yes |
| roles | [ [TimeseriesRole](#timeseriesrole) ] |  | No |
| annotations | [ [TimeseriesAnnotation](#timeseriesannotation) ] |  | No |
| variable | [Variable](#variable) |  | Yes |
| station |  |  | No |
| programme | [TimeseriesProgramme](#timeseriesprogramme) |  | Yes |

#### TimeseriesAnnotation

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| kind | integer |  | Yes |
| text | string |  | Yes |
| date_added | dateTime |  | Yes |
| approved | boolean |  | Yes |
| contributor_id | integer |  | Yes |
| timeseries_id | integer |  | Yes |

#### TimeseriesProgramme

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| name | string |  | Yes |
| longname | string |  | Yes |
| homepage | string |  | Yes |
| description | string |  | Yes |

#### TimeseriesRole

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| id | integer |  | Yes |
| role | string |  | Yes |
| status | string |  | Yes |
| contact_id | integer |  | Yes |

#### Variable

| Name | Type | Description | Required |
| ---- | ---- | ----------- | -------- |
| name | string | Name. Short variable-like name of the variable | Yes |
| longname | string | Longname. Long (explicit) name of the variable | Yes |
| displayname | string | Displayname. Display name of the variable | Yes |
| cf_standardname | string | Cf standardname. CF standard name of the variable if defined | Yes |
| units | string | Units. Physical units of variable | Yes |
| chemical_formula | string | Chemical formula. Chemical formula of variable(if applicable) | Yes |
| id | integer |  | Yes |

## controlled vocabulary

#### Rc_Vocabulary ####
  * RC_vocabulary: [  
 [0, 'PointOfContact', 'point of contact'],  
 [1, 'PrincipalInvestigator', 'principal investigator'],  
 [2, 'Originator', 'originator'],  
 [3, 'Contributor', 'contributor'],  
 [4, 'Collaborator', 'collaborator'],  
 [5, 'ResourceProvider', 'resource provider']]
#### Rs_Vocabulary ####
  * RS_vocabulary: [  
 [0, 'active', 'active'],  
 [1, 'inactive', 'inactive'],  
 [2, 'unknown', 'unknown']]
#### Ok_Vocabulary ####
  * OK_vocabulary: [  
 [1, 'Government', 'government'],  
 [2, 'Research', 'research'],  
 [3, 'International', 'international'],  
 [4, 'NonProfit', 'non-profit'],  
 [5, 'Commercial', 'commercial'],  
 [6, 'Individual', 'individual'],  
 [7, 'Other', 'other']]
#### Da_Vocabulary ####
  * DA_vocabulary: [  
 [0, 'ByAttribution', 'by attribution'],  
 [1, 'ShareAlike', 'share alike'],  
 [2, 'Restricted', 'restricted']]
#### Sf_Vocabulary ####
  * SF_vocabulary: [  
 [0, 'Hourly', 'hourly'],  
 [1, 'ThreeHourly', '3-hourly'],  
 [2, 'SixHourly', '6-hourly'],  
 [3, 'Daily', 'daily'],  
 [4, 'Weekly', 'weekly'],  
 [5, 'Monthly', 'monthly'],  
 [6, 'Yearly', 'yearly'],  
 [7, 'Irregular', 'irregular data samples of constant length'],  
 [8, 'Irregular2', 'irregular data samples of varying length']]
#### At_Vocabulary ####
  * AT_vocabulary: [  
 [0, 'Mean', 'mean'],  
 [1, 'Mean1Of2', 'mean of two values'],  
 [2, 'Mean1OfWeek', 'weekly mean'],  
 [3, 'Mean4Samples', 'mean out of 4 samples'],  
 [4, 'MeanMonth', 'monthly mean'],  
 [5, 'None', 'none'],  
 [6, 'Unknown', 'unknown']]
#### Ds_Vocabulary ####
  * DS_vocabulary: [  
 [0, 'Model', 'model'],  
 [1, 'Measurement', 'measurement']]
#### Mm_Vocabulary ####
  * MM_vocabulary: [  
 [0, 'UVAbsorption', 'UV absorption'],  
 [1, 'UnknownInstrument', 'unknown instrument']]
#### Cz_Vocabulary ####
  * CZ_vocabulary: [  
 [-1, 'Undefined', 'undefined'],  
 [0, 'Unclassified', 'unclassified'],  
 [1, 'WarmTemperateMoist', 'warm temperate moist'],  
 [2, 'WarmTemperateDry', 'warm temperate dry'],  
 [3, 'CoolTemperateMoist', 'cool temperate moist'],  
 [4, 'CoolTemperateDry', 'cool temperate dry'],  
 [5, 'PolarMoist', 'polar moist'],  
 [6, 'PolarDry', 'polar dry'],  
 [7, 'BorealMoist', 'boreal moist'],  
 [8, 'BorealDry', 'boreal dry'],  
 [9, 'TropicalMontane', 'tropical montane'],  
 [10, 'TropicalWet', 'tropical wet'],  
 [11, 'TropicalMoist', 'tropical moist'],  
 [12, 'TropicalDry', 'tropical dry']]
#### Cv_Vocabulary ####
  * CV_vocabulary: [  
 [0, 'NotChecked', 'not checked'],  
 [1, 'Verified', 'verified'],  
 [2, 'Plausible', 'plausible'],  
 [3, 'Doubtful', 'doubtful'],  
 [4, 'Unverifyable', 'not verifyable']]
#### St_Vocabulary ####
  * ST_vocabulary: [  
 [0, 'Unknown', 'unknown'],  
 [1, 'Background', 'background'],  
 [2, 'Traffic', 'traffic'],  
 [3, 'Industrial', 'industrial'],  
 [4, 'Other', 'other']]
#### Ta_Vocabulary ####
  * TA_vocabulary: [  
 [0, 'Unknown', 'unknown'],  
 [1, 'Urban', 'urban'],  
 [2, 'Suburban', 'suburban'],  
 [3, 'Rural', 'rural'],  
 [4, 'Remote', 'remote']]
#### Tc_Vocabulary ####
  * TC_vocabulary: [  
 [-1, 'Unknown', 'unknown'],  
 [0, 'Unclassified', 'unclassified'],  
 [1, 'RuralLowElevation', 'rural low elevation'],  
 [2, 'RuralHighElevation', 'rural high elevation'],  
 [3, 'Urban', 'urban']]
#### Tr_Vocabulary ####
  * TR_vocabulary: [  
 [-1, 'HTAPTier1Undefined', '-1 (undefined)'],  
 [1, 'HTAPTier1World', '1 (World)'],  
 [2, 'HTAPTier1OCN', '2 (OCN Non-arctic/Antarctic Ocean)'],  
 [3, 'HTAPTier1NAM', '3 (NAM US+Canada (upto 66 N; polar circle))'],  
 [4, 'HTAPTier1EUR', '4 (EUR Western + Eastern EU+Turkey (upto 66 N polar circle))'],  
 [5, 'HTAPTier1SAS', '5 (SAS South Asia: India, Nepal, Pakistan, Afghanistan, Bangadesh, Sri Lanka)'],  
 [6, 'HTAPTier1EAS', '6 (EAS East Asia: China, Korea, Japan)'],  
 [7, 'HTAPTier1SEA', '7 (SEA South East Asia)'],  
 [8, 'HTAPTier1PAN', '8 (PAN Pacific, Australia+ New Zealand)'],  
 [9, 'HTAPTier1NAF', '9 (NAF Northern Africa+Sahara+Sahel)'],  
 [10, 'HTAPTier1SAF', '10 (SAF Sub Saharan/sub Sahel Africa)'],  
 [11, 'HTAPTier1MDE', '11 (MDE Middle East: S. Arabia, Oman, etc, Iran, Iraq)'],  
 [12, 'HTAPTier1MCA', '12 (MCA Mexico, Central America, Caribbean, Guyanas, Venezuela, Columbia)'],  
 [13, 'HTAPTier1SAM', '13 (SAM S. America)'],  
 [14, 'HTAPTier1RBU', '14 (RBU Russia, Belarussia, Ukraine)'],  
 [15, 'HTAPTier1CAS', '15 (CAS Central Asia)'],  
 [16, 'HTAPTier1NPO', '16 (NPO Arctic Circle (North of 66 N) + Greenland)'],  
 [17, 'HTAPTier1SPO', '17 (SPO Antarctic)']]
#### Dl_Vocabulary ####
  * DL_vocabulary: [  
 [-1, 'Undefined', '-1 (undefined)'],  
 [0, 'Water', '0 (Water)'],  
 [1, 'EGNeedleleaf', '1  (Evergreen Needleleaf forest)'],  
 [2, 'EGBroadleaf', '2  (Evergreen Broadleaf forest)'],  
 [3, 'DCNeedleleaf', '3  (Deciduous Needleleaf forest)'],  
 [4, 'DCBroadleaf', '4  (Deciduous Broadleaf forest)'],  
 [5, 'MixedForest', '5  (Mixed forest)'],  
 [6, 'ClosedShrublands', '6  (Closed shrublands)'],  
 [7, 'OpenShrublands', '7  (Open shrublands)'],  
 [8, 'WoodySavannas', '8  (Woody savannas)'],  
 [9, 'Savannas', '9  (Savannas)'],  
 [10, 'Grasslands', '10  (Grasslands)'],  
 [11, 'Wetlands', '11  (Permanent wetlands)'],  
 [12, 'Croplands', '12  (Croplands)'],  
 [13, 'Urban', '13  (Urban and built-up)'],  
 [14, 'Mosaic', '14  (Cropland/Natural vegetation mosaic)'],  
 [15, 'Snow', '15  (Snow and ice)'],  
 [16, 'Barren', '16  (Barren or sparsely vegetated)'],  
 [255, 'Fill', '255 (Fill Value/Unclassified)']]
#### Rt_Vocabulary ####
  * RT_vocabulary: [  
 [0, 'String', 'str'],  
 [1, 'Integer', 'int'],  
 [2, 'Float', 'float']]
#### Df_Vocabulary ####
  * DF_vocabulary: [  
 [0, 'OK', 'OK'],  
 [1, 'OKPreliminary', 'OK preliminary'],  
 [2, 'OKModified', 'OK modified'],  
 [3, 'OKPreliminaryModified', 'OK preliminary modified'],  
 [4, 'Inconsistent', 'inconsistent'],  
 [5, 'InconsistentPreliminary', 'inconsistent preliminary'],  
 [6, 'Doubtful', 'doubtful'],  
 [7, 'DoubtfulPreliminary', 'doubtful preliminary'],  
 [8, 'DoubtfulModified', 'doubtful modified'],  
 [9, 'DoubtfulPreliminaryModified', 'doubtful preliminary modified'],  
 [10, 'Wrong', 'wrong'],  
 [11, 'WrongPreliminary', 'wrong preliminary'],  
 [12, 'NotCheckedPreliminary', 'not checked preliminary'],  
 [13, 'Changed', 'changed'],  
 [14, 'Estimated', 'estimated'],  
 [15, 'MissingValue', 'missing value']]


## REST API

### /controlled_vocabulary

#### GET
##### Summary:

Info

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |

### /variables/

#### GET
##### Summary:

Get Variables

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /variables/{name}

#### GET
##### Summary:

Get Variable

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /variables/id/{variable_id}

#### GET
##### Summary:

Get Variable

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| variable_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/persons/

#### GET
##### Summary:

Get All Persons

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/persons/id/{person_id}

#### GET
##### Summary:

Get Person

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| person_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/persons/{name}

#### GET
##### Summary:

Get Person

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/organisations/

#### GET
##### Summary:

Get All Organisations

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/organisations/id/{organisation_id}

#### GET
##### Summary:

Get Organisation

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| organisation_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/organisations/{name}

#### GET
##### Summary:

Get Organisation

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| name | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /contacts/

#### GET
##### Summary:

Get All Contacts

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta_core/

#### GET
##### Summary:

Get All Stationmeta Core

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta/

#### GET
##### Summary:

Get All Stationmeta

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta_core/{station_code}

#### GET
##### Summary:

Get Stationmeta Core

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| station_code | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /stationmeta/{station_code}

#### GET
##### Summary:

Get Stationmeta

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| station_code | path |  | Yes | string |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /timeseries/

#### GET
##### Summary:

Get All Timeseries

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /timeseries/{timeseries_id}

#### GET
##### Summary:

Get Timeseries

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| timeseries_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /data/

#### GET
##### Summary:

Get All Data

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| skip | query |  | No | integer |
| limit | query |  | No | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

### /data/{timeseries_id}

#### GET
##### Summary:

Get Data

##### Parameters

| Name | Located in | Description | Required | Schema |
| ---- | ---------- | ----------- | -------- | ---- |
| timeseries_id | path |  | Yes | integer |

##### Responses

| Code | Description |
| ---- | ----------- |
| 200 | Successful Response |
| 422 | Validation Error |

